==> owncloud-9.0.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/ast.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "La compartición sirvidor a sirvidor nun ta habilitada nesti sirvidor",
    "The mountpoint name contains invalid characters." : "El puntu de montax contien caracteres non válidos",
    "Invalid or untrusted SSL certificate" : "Certificáu SSL inválidu o ensín validar",
    "Couldn't add remote share" : "Nun pudo amestase una compartición remota",
    "Shared with you" : "Compartíos contigo",
    "Shared with others" : "Compartíos con otros",
    "Shared by link" : "Compartíos per enllaz",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quies amestar compartición remota {name} de {owner}@{remote}?",
    "Remote share" : "Compartición remota",
    "Remote share password" : "Contraseña de compartición remota",
    "Cancel" : "Encaboxar",
    "Add remote share" : "Amestar compartición remota",
    "Invalid ownCloud url" : "Url ownCloud inválida",
    "Shared by" : "Compartíos por",
    "Sharing" : "Compartiendo",
    "A file or folder has been <strong>shared</strong>" : "<strong>Compartióse</strong> un ficheru o direutoriu",
    "You shared %1$s with %2$s" : "Compartisti %1$s con %2$s",
    "You shared %1$s with group %2$s" : "Compartisti %1$s col grupu %2$s",
    "You shared %1$s via link" : "Compartisti %1$s per enllaz",
    "%2$s shared %1$s with you" : "%2$s compartió %1$s contigo",
    "Shares" : "Comparticiones",
    "This share is password-protected" : "Esta compartición tien contraseña protexida",
    "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
    "Password" : "Contraseña",
    "No entries found in this folder" : "Nenguna entrada en esta carpeta",
    "Name" : "Nome",
    "Share time" : "Compartir hora",
    "Sorry, this link doesn’t seem to work anymore." : "Sentímoslo, esti enllaz paez que yá nun furrula.",
    "Reasons might be:" : "Les razones pueden ser: ",
    "the item was removed" : "desanicióse l'elementu",
    "the link expired" : "l'enllaz caducó",
    "sharing is disabled" : "la compartición ta deshabilitada",
    "For more info, please ask the person who sent this link." : "Pa más información, entrúga-y a la persona qu'unvió esti enllaz",
    "Add to your ownCloud" : "Amestar al to ownCloud",
    "Download" : "Baxar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Enllaz direutu"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/ast.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "La compartición sirvidor a sirvidor nun ta habilitada nesti sirvidor",
    "The mountpoint name contains invalid characters." : "El puntu de montax contien caracteres non válidos",
    "Invalid or untrusted SSL certificate" : "Certificáu SSL inválidu o ensín validar",
    "Couldn't add remote share" : "Nun pudo amestase una compartición remota",
    "Shared with you" : "Compartíos contigo",
    "Shared with others" : "Compartíos con otros",
    "Shared by link" : "Compartíos per enllaz",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quies amestar compartición remota {name} de {owner}@{remote}?",
    "Remote share" : "Compartición remota",
    "Remote share password" : "Contraseña de compartición remota",
    "Cancel" : "Encaboxar",
    "Add remote share" : "Amestar compartición remota",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nun s'atopó nenguna instalación ownCloud (7 o cimera) en { } remotu",
    "Invalid ownCloud url" : "Url ownCloud inválida",
    "Shared by" : "Compartíos por",
    "Sharing" : "Compartiendo",
    "A file or folder has been <strong>shared</strong>" : "<strong>Compartióse</strong> un ficheru o direutoriu",
    "You shared %1$s with %2$s" : "Compartisti %1$s con %2$s",
    "You shared %1$s with group %2$s" : "Compartisti %1$s col grupu %2$s",
    "You shared %1$s via link" : "Compartisti %1$s per enllaz",
    "%2$s shared %1$s with you" : "%2$s compartió %1$s contigo",
    "Shares" : "Comparticiones",
    "This share is password-protected" : "Esta compartición tien contraseña protexida",
    "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
    "Password" : "Contraseña",
    "No entries found in this folder" : "Nenguna entrada en esta carpeta",
    "Name" : "Nome",
    "Share time" : "Compartir hora",
    "Sorry, this link doesn’t seem to work anymore." : "Sentímoslo, esti enllaz paez que yá nun furrula.",
    "Reasons might be:" : "Les razones pueden ser: ",
    "the item was removed" : "desanicióse l'elementu",
    "the link expired" : "l'enllaz caducó",
    "sharing is disabled" : "la compartición ta deshabilitada",
    "For more info, please ask the person who sent this link." : "Pa más información, entrúga-y a la persona qu'unvió esti enllaz",
    "Add to your ownCloud" : "Amestar al to ownCloud",
    "Download" : "Baxar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Enllaz direutu"
},
"nplurals=2; plural=(n != 1);");
